mlpy.learners.native.logistic\_regression module
================================================

.. automodule:: mlpy.learners.native.logistic_regression
   :members:
   :undoc-members:
   :show-inheritance:
